dcor_shared
===========

|PyPI Version| |Build Status| |Coverage Status|

Functionalities shared by the DCOR CKAN extensions


Installation
------------
To install the latest release, simply run:

::

    pip install dcor_shared


.. |PyPI Version| image:: https://img.shields.io/pypi/v/dcor_shared.svg
   :target: https://pypi.python.org/pypi/dcor_shared
.. |Build Status| image:: https://img.shields.io/travis/DCOR-dev/dcor_shared.svg?label=tests
   :target: https://travis-ci.com/DCOR-dev/dcor_shared
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/DCOR-dev/dcor_shared/master.svg
   :target: https://codecov.io/gh/DCOR-dev/dcor_shared
